==> boot-kit-1.0.0-sources.jar: com/ovopark/boot/kit/util/Listkit.java <==
package com.ovopark.boot.kit.util;

import java.util.List;

import com.ovopark.boot.kit.lang.StrKit;
import com.ovopark.boot.kit.reflect.ReflectKit;
import com.ovopark.boot.utils.lang.ConvertUtils;

/**
 * 
 * @ClassName:  Listkit   
 * @Description:TODO(List工具类)   
 * @author: Remiel_Mercy 
 * @date:   2019年1月8日 下午7:08:29   
 *     
 * @Copyright: 2019 www.ovopark.com Inc. All rights reserved.
 */
public class Listkit {
	
	/**
	 * 
	 * @Title: ValidDuplication   
	 * @Description: TODO(验证对象集合制定的key是否有重复的value)   
	 * @param: @param list 对象集合
	 * @param: @param key 指定名称
	 * @param: @return      
	 * @return: boolean      
	 * @throws
	 */
	public static <T> boolean ValidDuplication(List<T> list,String key ) {
		for (int i = 0; i < list.size(); i++) {
			Object t1=list.get(i);
			Object value1=ReflectKit.getFieldValue(t1, key);
			for (int j = 0; j < list.size(); j++) {
				Object t2=list.get(j);
				Object value2=ReflectKit.getFieldValue(t2, key);
				if(value1.equals(value2)&&i!=j) {
					return true;
				}
			}
		}
		return false;
	}
	/**
	 * 
	 * @Title: ValidDuplication2Value   
	 * @Description: TODO(验证对象集合制定的key是否有重复的value,且返回这个值)   
	 * @param: @param list
	 * @param: @param key
	 * @param: @return      
	 * @return: String      
	 * @throws
	 */
	public static <T> String ValidDuplication2Value(List<T> list,String key ) {
		for (int i = 0; i < list.size(); i++) {
			Object t1=list.get(i);
			Object value1=ReflectKit.getFieldValue(t1, key);
			for (int j = 0; j < list.size(); j++) {
				Object t2=list.get(j);
				Object value2=ReflectKit.getFieldValue(t2, key);
				if(value1.equals(value2)&&i!=j) {
					return ConvertUtils.toStr(value1);
				}
			}
		}
		return null;
	}
	
	public static boolean isEmpty(List<?> list) {
		if(list!=null&&!list.isEmpty()) {
			return false;
		}else {
			return true;
		}
	}
}

==> boot-kit-1.0.2-sources.jar: com/ovopark/boot/kit/util/Listkit.java <==
package com.ovopark.boot.kit.util;

import java.util.List;

import com.ovopark.boot.kit.reflect.ReflectKit;
import com.ovopark.boot.utils.lang.ConvertUtils;

/**
 * 
 * @ClassName:  Listkit   
 * @Description:TODO(List工具类)   
 * @author: Remiel_Mercy 
 * @date:   2019年1月8日 下午7:08:29   
 *     
 * @Copyright: 2019 www.ovopark.com Inc. All rights reserved.
 */
public class Listkit {
	
	/**
	 * 
	 * @Title: ValidDuplication   
	 * @Description: TODO(验证对象集合制定的key是否有重复的value)   
	 * @param: @param list 对象集合
	 * @param: @param key 指定名称
	 * @param: @return      
	 * @return: boolean      
	 * @throws
	 */
	public static <T> boolean ValidDuplication(List<T> list,String key ) {
		for (int i = 0; i < list.size(); i++) {
			Object t1=list.get(i);
			Object value1=ReflectKit.getFieldValue(t1, key);
			for (int j = 0; j < list.size(); j++) {
				Object t2=list.get(j);
				Object value2=ReflectKit.getFieldValue(t2, key);
				if(value1.equals(value2)&&i!=j) {
					return true;
				}
			}
		}
		return false;
	}
	/**
	 * 
	 * @Title: ValidDuplication2Value   
	 * @Description: TODO(验证对象集合制定的key是否有重复的value,且返回这个值)   
	 * @param: @param list
	 * @param: @param key
	 * @param: @return      
	 * @return: String      
	 * @throws
	 */
	public static <T> String ValidDuplication2Value(List<T> list,String key ) {
		for (int i = 0; i < list.size(); i++) {
			Object t1=list.get(i);
			Object value1=ReflectKit.getFieldValue(t1, key);
			for (int j = 0; j < list.size(); j++) {
				Object t2=list.get(j);
				Object value2=ReflectKit.getFieldValue(t2, key);
				if(value1.equals(value2)&&i!=j) {
					return ConvertUtils.toStr(value1);
				}
			}
		}
		return null;
	}
	
	public static boolean isEmpty(List<?> list) {
		if(list!=null&&!list.isEmpty()) {
			return false;
		}else {
			return true;
		}
	}
	
	/**
	 * @Title: convertListToString   
	 * @Description: TODO(将List<String>集合 转化为String 如{"aaa","bbb"} To 'aaa','bbb')   
	 * @param: @param strlist
	 * @param: @return      
	 * @return: String      
	 * @throws
	 */
	public static String convertListToString(List<String> strlist) {
		StringBuffer sb = new StringBuffer();
		if (!isEmpty(strlist)) {
			for (int i = 0; i < strlist.size(); i++) {
				if (i == 0) {
					sb.append("'").append(strlist.get(i)).append("'");
				} else {
					sb.append(",").append("'").append(strlist.get(i)).append("'");
				}
			}
		}
		return sb.toString();
	}
	
	
}
